# We require at the least the first release java-1.6.0-openjdk 
# with IcedTea6 1.10
%define min_openjdk_version 0:1.6.0.0-14.b22.3
%define multilib_arches ppc64 sparc64 x86_64

# Version of java
%define javaver 1.6.0

# Alternatives priority
%define priority 17000

%ifarch %{ix86}
%define archinstall i386
%endif
%ifarch x86_64
%define archinstall amd64
%endif
# 32 bit sparc, optimized for v9
%ifarch sparcv9
%define archinstall sparc
%endif
# 64 bit sparc
%ifarch sparc64
%define archinstall sparcv9
%endif

%ifarch %{multilib_arches}
%define javadir     %{_jvmdir}/java-%{javaver}-openjdk.%{_arch}
%define jredir      %{_jvmdir}/jre-%{javaver}-openjdk.%{_arch}
%define jre6dir     %{_jvmdir}/jre-1.6.0-openjdk.%{_arch}
%define javaplugin  libjavaplugin.so.%{_arch}
%else
%define javadir     %{_jvmdir}/java-%{javaver}-openjdk
%define jredir      %{_jvmdir}/jre-%{javaver}-openjdk
%define jre6dir     %{_jvmdir}/jre-1.6.0-openjdk
%define javaplugin  libjavaplugin.so
%endif

%define binsuffix      .itweb

Name:		icedtea-web
Version:	1.3.2
Release:	%mkrel 1
Summary:	Additional Java components for OpenJDK

Group:      Networking/WWW
License:    LGPLv2+ and GPLv2 with exceptions
URL:        http://icedtea.classpath.org/wiki/IcedTea-Web
Source0:    http://icedtea.classpath.org/download/source/%{name}-%{version}.tar.gz
BuildRequires:  java-%{javaver}-openjdk-devel
BuildRequires:  desktop-file-utils
#BuildRequires:  gecko-devel
BuildRequires:  glib2-devel
BuildRequires:  gtk2-devel
BuildRequires:  xulrunner-devel
BuildRequires:  zip

# For functionality and the OpenJDK dirs
Requires:      java-%{javaver}-openjdk

# For the mozilla plugin dir
Requires(pre):  mozilla-filesystem%{?_isa}
Requires:       mozilla-filesystem%{?_isa}

# Post requires alternatives to install plugin alternative.
Requires(post): update-alternatives

# Postun requires alternatives to uninstall plugin alternative.
Requires(postun): update-alternatives

# Standard JPackage plugin provides.
Provides: java-plugin = %{javaver}

# For the mozilla plugin dir
Requires:       mozilla-filesystem%{?_isa}

Provides:   java-1.6.0-openjdk-plugin = %{min_openjdk_version}
Obsoletes:  java-1.6.0-openjdk-plugin <= %{min_openjdk_version}

# IcedTea is only built on these archs for now
ExclusiveArch: x86_64 %{ix86} %{arm}

%description
The IcedTea-Web project provides a Java web browser plugin, an implementation
of Java Web Start (originally based on the Netx project) and a settings tool to
manage deployment settings for the aforementioned plugin and Web Start
implementations. 

%post
if [ $1 -gt 1 ]
then
alternatives --remove %{javaplugin} \
  %{jre6dir}/lib/%{archinstall}/IcedTeaPlugin.so 2>/dev/null || :
fi

%posttrans
alternatives \
  --install %{_libdir}/mozilla/plugins/libjavaplugin.so %{javaplugin} \
  %{_libdir}/IcedTeaPlugin.so %{priority} \
  --slave %{_bindir}/javaws javaws %{_prefix}/bin/javaws%{binsuffix} \
  --slave %{_mandir}/man1/javaws.1.xz javaws.1.xz \
  %{_mandir}/man1/javaws-itweb.1.xz

exit 0

%postun
if [ $1 -eq 0 ]
then
  alternatives --remove %{javaplugin} \
    %{_libdir}/IcedTeaPlugin.so
fi

exit 0

%files
%{_bindir}/*
%{_libdir}/IcedTeaPlugin.so
%{_datadir}/applications
%{_datadir}/icedtea-web
%{_datadir}/man/man1/javaws-itweb.*
%{_datadir}/pixmaps/*
%doc NEWS README COPYING

#--------------------------------------------------------------------

%package javadoc
Summary:    API documentation for IcedTea-Web
Group:      Development/Other
Requires:   jpackage-utils
BuildArch:  noarch

%description javadoc
This package contains Javadocs for the IcedTea-Web project.

%files javadoc
%{_datadir}/javadoc/%{name}
%doc COPYING

#--------------------------------------------------------------------

%prep
%setup -q

%build
autoconf
%configure2_5x \
    --with-pkgversion=%_real_vendor-%{release}-%{_arch} \
    --docdir=%{_datadir}/javadoc/%{name} \
    --with-jdk-home=%{javadir} \
    --with-jre-home=%{jredir} \
    --program-suffix=%{binsuffix} \

make CXXFLAGS="$RPM_OPT_FLAGS"

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

# Move javaws man page to a more specific name
mv $RPM_BUILD_ROOT/%{_mandir}/man1/javaws.1 $RPM_BUILD_ROOT/%{_mandir}/man1/javaws-itweb.1

# Install desktop files.
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/{applications,pixmaps}
cp javaws.png $RPM_BUILD_ROOT%{_datadir}/pixmaps
desktop-file-install --vendor ''\
  --dir $RPM_BUILD_ROOT%{_datadir}/applications javaws.desktop
desktop-file-install --vendor ''\
  --dir $RPM_BUILD_ROOT%{_datadir}/applications itweb-settings.desktop



%changelog

* Wed Apr 17 2013 luigiwalser <luigiwalser> 1.3.2-1.mga2
+ Revision: 410343
- 1.3.2 (fixes CVE-2013-1926 and CVE-2013-1927)
- 1.3.1 (fixes CVE-2012-4540)
- 1.3
- 1.2.1 (fixes CVE-2012-3422 and CVE-2012-3423)

  + dmorgan <dmorgan>
    - Allow to build on arm as well
    - Fix Requires(post) ( mga #5917)

* Wed May 16 2012 dmorgan <dmorgan> 1.2-3.mga2
+ Revision: 235770
- Requires mozilla-filesystem for update-alternatives to work

* Thu Apr 19 2012 dmorgan <dmorgan> 1.2-2.mga2
+ Revision: 231733
- Fix dandling links ( mga #4631)

* Tue Mar 20 2012 dmorgan <dmorgan> 1.2-1.mga2
+ Revision: 225136
- New version 1.2

* Sat Dec 17 2011 gil <gil> 1.1.4-1.mga2
+ Revision: 183243
- update to 1.1.4

* Tue Oct 18 2011 dmorgan <dmorgan> 1.1.3-1.mga2
+ Revision: 156434
- Do not own std dirs
- New version 1.1.3

  + gil <gil>
    - New version

* Tue Sep 20 2011 fwang <fwang> 1.0.4-1.mga2
+ Revision: 145970
- fix group
- fix bindir
- fix linkage

  + gil <gil>
    - update to 1.0.4

* Thu Jun 16 2011 dmorgan <dmorgan> 1.0.3-1.mga2
+ Revision: 108216
- New version 1.0.3

* Mon Apr 11 2011 tmb <tmb> 1.0.2-5.mga1
+ Revision: 83483
- fix ExclusiveArch so i586 gets built

* Mon Apr 11 2011 tmb <tmb> 1.0.2-4.mga1
+ Revision: 83472
- rebuild for missing package on i586

* Sat Apr 09 2011 dmorgan <dmorgan> 1.0.2-3.mga1
+ Revision: 82529
- Better obsoletes

* Sat Apr 09 2011 dmorgan <dmorgan> 1.0.2-2.mga1
+ Revision: 82525
- Fix openjdk version for the obsolete/provides
  Fix Groups
  Fix layout

* Sat Apr 09 2011 ahmad <ahmad> 1.0.2-1.mga1
+ Revision: 82490
- adapt the spec to Mageia
- add BR zip
- imported package icedtea-web

